@@ -3,9 +3,9 @@
 Module      : HsLua.Core.Primary
 Copyright   : © 2007–2012 Gracjan Polak;
               © 2012–2016 Ömer Sinan Ağacan;
-              © 2017-2022 Albert Krewinkel
+              © 2017-2023 Albert Krewinkel
 License     : MIT
-Maintainer  : Albert Krewinkel <tarleb+hslua@zeitkraut.de>
+Maintainer  : Albert Krewinkel <tarleb@hslua.org>
 Stability   : beta
 Portability : non-portable (depends on GHC)
 
@@ -888,6 +888,15 @@ setiuservalue :: StackIndex {- ^ index -} -> Int {- ^ n -} -> LuaE e Bool
 setiuservalue idx n = liftLua $ \l ->
   fromLuaBool <$!> lua_setiuservalue l idx (fromIntegral n)
 
+-- | Sets the warning function to be used by Lua to emit warnings (see
+-- 'WarnFunction'). The @ud@ parameter sets the value @ud@ passed to the
+-- warning function.
+setwarnf :: WarnFunction -- ^ f
+         -> Ptr ()       -- ^ ud
+         -> LuaE e ()
+setwarnf f ud = liftLua $ \l ->
+  lua_setwarnf l f ud
+
 -- |  Returns the status of this Lua thread.
 --
 -- The status can be 'OK' for a normal thread, an error value if the
